"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useCopilotMessage_unstable", {
    enumerable: true,
    get: function() {
        return useCopilotMessage_unstable;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _reactcomponents = require("@fluentui/react-components");
const _reactsharedcontexts = require("@fluentui/react-shared-contexts");
const _reactutilities = require("@fluentui/react-utilities");
const _useMessageAttributesV2 = require("../../utils/useMessageAttributesV2");
const _AiGeneratedDisclaimer = require("../AiGeneratedDisclaimer");
const _reactprovider = require("@fluentui-copilot/react-provider");
const useCopilotMessage_unstable = (props, ref)=>{
    const { announcement, accessibleHeading, loadingState = 'none' } = props;
    const messageId = (0, _reactcomponents.useId)('copilot-message-', props.id);
    const headingId = `${messageId}-title`;
    const rootRef = _react.useRef(null);
    const { announce } = (0, _reactsharedcontexts.useAnnounce_unstable)();
    const mode = (0, _reactprovider.useCopilotMode)(props.mode);
    // timeout for announcing "loading" at 10s intervals
    const [setLoadingAnnounceTimeout, clearLoadingAnnounceTimeout] = (0, _reactutilities.useTimeout)();
    // track whether the message has loaded; this should only change once from false -> true
    const hasLoaded = _react.useRef(loadingState === 'none');
    // if the message is loading when first mounted, kick off loading announcements
    const isFirstMount = (0, _reactutilities.useFirstMount)();
    if (isFirstMount && !announcement && loadingState !== 'none') {
        const announceLoading = ()=>{
            // check for the announcement when this function runs as well
            if (!announcement) {
                var _rootRef_current;
                let messageText = 'loading...';
                if (loadingState === 'loading' && ((_rootRef_current = rootRef.current) === null || _rootRef_current === void 0 ? void 0 : _rootRef_current.textContent)) {
                    messageText = rootRef.current.textContent;
                }
                announce(messageText, {
                    batchId: messageId
                });
            }
            setLoadingAnnounceTimeout(()=>{
                announceLoading();
            }, 5000);
        };
        announceLoading();
    }
    // fire tabster event on first mount to focus new message when it appears
    _react.useEffect(()=>{
        if (isFirstMount) {
            var _rootRef_current;
            const tabsterMoverEvent = new CustomEvent('tabster:mover:memorized-element', {
                bubbles: true,
                detail: {
                    memorizedElement: rootRef.current
                }
            });
            (_rootRef_current = rootRef.current) === null || _rootRef_current === void 0 ? void 0 : _rootRef_current.dispatchEvent(tabsterMoverEvent);
        }
    }, [
        isFirstMount
    ]);
    // announce the announcement message every time the prop changes
    _react.useEffect(()=>{
        if (announcement) {
            clearLoadingAnnounceTimeout();
            announce(announcement, {
                batchId: messageId
            });
        }
    }, [
        announce,
        announcement,
        clearLoadingAnnounceTimeout,
        messageId
    ]);
    // automatically announce when loading is complete, if announcement is not defined
    _react.useEffect(()=>{
        if (!hasLoaded.current && loadingState === 'none') {
            // flag message as having finished loading, and stop loading announcements
            hasLoaded.current = true;
            clearLoadingAnnounceTimeout();
            if (announcement === undefined) {
                var _rootRef_current;
                const messageText = (_rootRef_current = rootRef.current) === null || _rootRef_current === void 0 ? void 0 : _rootRef_current.textContent;
                // clear any queued batched announcements and announce the full message
                announce('', {
                    batchId: messageId
                });
                messageText && announce(messageText);
            }
        }
    }, [
        announce,
        announcement,
        clearLoadingAnnounceTimeout,
        messageId,
        loadingState
    ]);
    const focusAttributes = (0, _reactcomponents.useArrowNavigationGroup)({
        axis: 'horizontal',
        memorizeCurrent: true
    });
    return {
        loadingState,
        mode,
        components: {
            root: 'div',
            accessibleHeading: 'h6',
            avatar: 'div',
            name: 'div',
            disclaimer: 'div',
            content: 'div',
            footnote: 'div',
            actions: 'div',
            progress: _reactcomponents.ProgressBar
        },
        root: _reactcomponents.slot.always((0, _reactutilities.getIntrinsicElementProps)('div', {
            ref: (0, _reactcomponents.useMergedRefs)(rootRef, ref),
            ...(0, _useMessageAttributesV2.useMessageAttributes)({
                contentId: messageId,
                headingId,
                defaultFocused: props.defaultFocused
            }),
            'aria-busy': loadingState === 'streaming' ? true : undefined,
            // `content` is a slot and it's type clashes with the HTMLElement `content` attribute
            ...(0, _reactutilities.omit)(props, [
                'content'
            ])
        }), {
            elementType: 'div'
        }),
        accessibleHeading: _reactcomponents.slot.optional(accessibleHeading, {
            defaultProps: {
                children: 'Copilot said: ',
                id: headingId
            },
            elementType: 'h6',
            renderByDefault: true
        }),
        avatar: _reactcomponents.slot.always(props.avatar, {
            elementType: 'div'
        }),
        name: _reactcomponents.slot.always(props.name, {
            elementType: 'div'
        }),
        disclaimer: _reactcomponents.slot.optional(props.disclaimer, {
            defaultProps: {
                children: /*#__PURE__*/ _react.createElement(_AiGeneratedDisclaimer.AiGeneratedDisclaimer, null, " AI-generated content may be incorrect ")
            },
            elementType: 'div',
            renderByDefault: true
        }),
        content: _reactcomponents.slot.optional(props.content, {
            defaultProps: {
                children: props.children,
                dir: 'auto',
                id: messageId
            },
            elementType: 'div',
            renderByDefault: props.children !== undefined
        }),
        footnote: _reactcomponents.slot.optional(props.footnote, {
            elementType: 'div'
        }),
        actions: _reactcomponents.slot.optional(props.actions, {
            defaultProps: {
                ...focusAttributes,
                role: 'toolbar'
            },
            elementType: 'div'
        }),
        progress: _reactcomponents.slot.optional(props.progress, {
            defaultProps: {
                'aria-label': 'Loading',
                shape: 'square',
                thickness: 'large'
            },
            elementType: _reactcomponents.ProgressBar,
            renderByDefault: loadingState === 'loading'
        })
    };
}; //# sourceMappingURL=useCopilotMessage.js.map
