"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "useUserMessage_unstable", {
    enumerable: true,
    get: function() {
        return useUserMessage_unstable;
    }
});
const _interop_require_wildcard = require("@swc/helpers/_/_interop_require_wildcard");
const _react = /*#__PURE__*/ _interop_require_wildcard._(require("react"));
const _reactcomponents = require("@fluentui/react-components");
const _reactsharedcontexts = require("@fluentui/react-shared-contexts");
const _useMessageAttributesV2 = require("../../utils/useMessageAttributesV2");
const _useUserMessagePositioning = require("../../utils/useUserMessagePositioning");
const _useActionBarSlot = require("../../utils/useActionBarSlot");
const _reactutilities = require("@fluentui/react-utilities");
const useUserMessage_unstable = (props, ref)=>{
    const { announcement, accessibleHeading, actionBarAccessibleButton, actionBar, message, timestamp } = props;
    const messageId = (0, _reactcomponents.useId)('user-message-', props.id);
    const headingId = `${messageId}-title`;
    const [userMessagePopupRef, userMessageTargetRef] = (0, _useUserMessagePositioning.useUserMessagePositioning)(props);
    const { announce } = (0, _reactsharedcontexts.useAnnounce_unstable)();
    const { ...copilotChatAttributes } = (0, _useMessageAttributesV2.useMessageAttributes)({
        contentId: messageId,
        headingId
    });
    const [isHovered, setIsHovered] = _react.useState(false);
    const [isFocused, setIsFocused] = _react.useState(false);
    const rootRef = _react.useRef(null);
    _react.useEffect(()=>{
        announcement && announce(announcement, {
            batchId: messageId
        });
    }, [
        announce,
        announcement,
        messageId
    ]);
    const state = {
        components: {
            root: 'div',
            accessibleHeading: 'h5',
            timestamp: 'span',
            actionBarAccessibleButton: 'button',
            actionBar: _reactcomponents.Toolbar,
            message: 'div'
        },
        root: _reactcomponents.slot.always((0, _reactcomponents.getIntrinsicElementProps)('div', {
            ref: (0, _reactutilities.useMergedRefs)(rootRef, ref),
            ...copilotChatAttributes,
            ...props
        }), {
            elementType: 'div'
        }),
        accessibleHeading: _reactcomponents.slot.optional(accessibleHeading, {
            defaultProps: {
                children: 'You said: ',
                id: headingId
            },
            elementType: 'h5',
            renderByDefault: true
        }),
        timestamp: _reactcomponents.slot.optional(timestamp, {
            elementType: 'span'
        }),
        actionBarAccessibleButton: actionBar ? _reactcomponents.slot.optional(actionBarAccessibleButton, {
            defaultProps: {
                'aria-label': 'More actions',
                tabIndex: -1
            },
            ...copilotChatAttributes,
            elementType: 'button',
            renderByDefault: true
        }) : undefined,
        actionBar: (0, _useActionBarSlot.useActionBarSlot)(actionBar, {
            popoverRef: userMessagePopupRef,
            triggerRef: userMessageTargetRef,
            isFocused,
            isHovered
        }),
        message: _reactcomponents.slot.always(message, {
            defaultProps: {
                children: props.children,
                id: messageId,
                ref: userMessageTargetRef
            },
            elementType: 'div'
        })
    };
    const onBlur = (e)=>{
        const nextFocusedElement = e.relatedTarget;
        if (nextFocusedElement !== rootRef.current && !(0, _reactutilities.elementContains)(rootRef.current, nextFocusedElement)) {
            setIsFocused(false);
        }
    };
    const onFocus = (e)=>{
        setIsFocused(true);
    };
    const onMouseEnter = (e)=>{
        setIsHovered(true);
    };
    const onMouseLeave = (e)=>{
        setIsHovered(false);
    };
    state.root.onBlur = (0, _reactcomponents.useEventCallback)((0, _reactcomponents.mergeCallbacks)(onBlur, props.onBlur));
    state.root.onFocus = (0, _reactcomponents.useEventCallback)((0, _reactcomponents.mergeCallbacks)(onFocus, props.onFocus));
    state.root.onMouseEnter = (0, _reactcomponents.useEventCallback)((0, _reactcomponents.mergeCallbacks)(onMouseEnter, props.onMouseEnter));
    state.root.onMouseLeave = (0, _reactcomponents.useEventCallback)((0, _reactcomponents.mergeCallbacks)(onMouseLeave, props.onMouseLeave));
    return state;
}; //# sourceMappingURL=useUserMessage.js.map
