import { useId, slot, isResolvedShorthand, useMergedRefs } from '@fluentui/react-utilities';
import { Toolbar } from '@fluentui/react-components';
/**
 * @internal
 * @returns  actionBar slot with desired behaviour and props
 */
export function useActionBarSlot(actionBarSlotFromProp, options) {
  const {
    popoverRef,
    isFocused,
    isHovered
  } = options;
  const actionBarId = useId('fluentai-actionbar', isResolvedShorthand(actionBarSlotFromProp) ? actionBarSlotFromProp.id : undefined);
  const actionBarSlot = slot.optional(actionBarSlotFromProp, {
    elementType: Toolbar,
    defaultProps: {
      id: actionBarId,
      size: 'small'
    }
  });
  /**
  * Clicking on the actionBar should never blur the trigger
  * in a UserMessage
  */
  const actionBarRef = useMergedRefs(actionBarSlot === null || actionBarSlot === void 0 ? void 0 : actionBarSlot.ref, popoverRef);
  if (actionBarSlot) {
    actionBarSlot.ref = actionBarRef;
  }
  return isFocused || isHovered ? actionBarSlot : undefined;
}
//# sourceMappingURL=useActionBarSlot.js.map